@@ -10,8 +10,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-ENABLE_SSL = False
-DEFAULT_HOST = 'localhost'
-DEFAULT_PORT = 8080
 DEFAULT_TIMEOUT_MS = 10000
 DEFAULT_NAMESPACE_NAME = 'default'
+DEFAULT_MARQUEZ_BACKEND = 'file'
+DEFAULT_MARQUEZ_URL = 'http://localhost:5000'
+DEFAULT_MARQUEZ_FILE = '/tmp/marquez.client.requests.log'
